==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hdinsight/kotlin/inputs/AutoscaleScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hdinsight.kotlin.inputs

import com.pulumi.azurenative.hdinsight.inputs.AutoscaleScheduleArgs.builder
import com.pulumi.azurenative.hdinsight.kotlin.enums.DaysOfWeek
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Parameters for a schedule-based autoscale rule, consisting of an array of days + a time and capacity
 * @property days Days of the week for a schedule-based autoscale rule
 * @property timeAndCapacity Time and capacity for a schedule-based autoscale rule
 */
public data class AutoscaleScheduleArgs(
    public val days: Output<List<Either<String, DaysOfWeek>>>? = null,
    public val timeAndCapacity: Output<AutoscaleTimeAndCapacityArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hdinsight.inputs.AutoscaleScheduleArgs> {
    override fun toJava(): com.pulumi.azurenative.hdinsight.inputs.AutoscaleScheduleArgs =
        com.pulumi.azurenative.hdinsight.inputs.AutoscaleScheduleArgs.builder()
            .days(
                days?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 ->
                            args0.let({ args0 -> args0.toJava() })
                        })
                    })
                }),
            )
            .timeAndCapacity(
                timeAndCapacity?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [AutoscaleScheduleArgs].
 */
@PulumiTagMarker
public class AutoscaleScheduleArgsBuilder internal constructor() {
    private var days: Output<List<Either<String, DaysOfWeek>>>? = null

    private var timeAndCapacity: Output<AutoscaleTimeAndCapacityArgs>? = null

    /**
     * @param value Days of the week for a schedule-based autoscale rule
     */
    @JvmName("tyhedjtvesmpnlcb")
    public suspend fun days(`value`: Output<List<Either<String, DaysOfWeek>>>) {
        this.days = value
    }

    @JvmName("natvvswjydueebxu")
    public suspend fun days(vararg values: Output<Either<String, DaysOfWeek>>) {
        this.days = Output.all(values.asList())
    }

    /**
     * @param values Days of the week for a schedule-based autoscale rule
     */
    @JvmName("ujgsmwprxghyxqel")
    public suspend fun days(values: List<Output<Either<String, DaysOfWeek>>>) {
        this.days = Output.all(values)
    }

    /**
     * @param value Time and capacity for a schedule-based autoscale rule
     */
    @JvmName("sxawadojqlynpfra")
    public suspend fun timeAndCapacity(`value`: Output<AutoscaleTimeAndCapacityArgs>) {
        this.timeAndCapacity = value
    }

    /**
     * @param value Days of the week for a schedule-based autoscale rule
     */
    @JvmName("clllxjgqjtjcxnwp")
    public suspend fun days(`value`: List<Either<String, DaysOfWeek>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.days = mapped
    }

    /**
     * @param values Days of the week for a schedule-based autoscale rule
     */
    @JvmName("ltuewlwpduhoruoi")
    public suspend fun days(vararg values: Either<String, DaysOfWeek>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.days = mapped
    }

    /**
     * @param value Time and capacity for a schedule-based autoscale rule
     */
    @JvmName("vrvddcocadlhhigq")
    public suspend fun timeAndCapacity(`value`: AutoscaleTimeAndCapacityArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeAndCapacity = mapped
    }

    /**
     * @param argument Time and capacity for a schedule-based autoscale rule
     */
    @JvmName("ujvubuyylkiuyyxb")
    public suspend
    fun timeAndCapacity(argument: suspend AutoscaleTimeAndCapacityArgsBuilder.() -> Unit) {
        val toBeMapped = AutoscaleTimeAndCapacityArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.timeAndCapacity = mapped
    }

    internal fun build(): AutoscaleScheduleArgs = AutoscaleScheduleArgs(
        days = days,
        timeAndCapacity = timeAndCapacity,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hdinsight/kotlin/inputs/AutoscaleScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hdinsight.kotlin.inputs

import com.pulumi.azurenative.hdinsight.inputs.AutoscaleScheduleArgs.builder
import com.pulumi.azurenative.hdinsight.kotlin.enums.DaysOfWeek
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Parameters for a schedule-based autoscale rule, consisting of an array of days + a time and capacity
 * @property days Days of the week for a schedule-based autoscale rule
 * @property timeAndCapacity Time and capacity for a schedule-based autoscale rule
 */
public data class AutoscaleScheduleArgs(
    public val days: Output<List<Either<String, DaysOfWeek>>>? = null,
    public val timeAndCapacity: Output<AutoscaleTimeAndCapacityArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hdinsight.inputs.AutoscaleScheduleArgs> {
    override fun toJava(): com.pulumi.azurenative.hdinsight.inputs.AutoscaleScheduleArgs =
        com.pulumi.azurenative.hdinsight.inputs.AutoscaleScheduleArgs.builder()
            .days(
                days?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 ->
                            args0.let({ args0 -> args0.toJava() })
                        })
                    })
                }),
            )
            .timeAndCapacity(
                timeAndCapacity?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [AutoscaleScheduleArgs].
 */
@PulumiTagMarker
public class AutoscaleScheduleArgsBuilder internal constructor() {
    private var days: Output<List<Either<String, DaysOfWeek>>>? = null

    private var timeAndCapacity: Output<AutoscaleTimeAndCapacityArgs>? = null

    /**
     * @param value Days of the week for a schedule-based autoscale rule
     */
    @JvmName("vsrydngamurrtupu")
    public suspend fun days(`value`: Output<List<Either<String, DaysOfWeek>>>) {
        this.days = value
    }

    @JvmName("vnnagbiwspoixqab")
    public suspend fun days(vararg values: Output<Either<String, DaysOfWeek>>) {
        this.days = Output.all(values.asList())
    }

    /**
     * @param values Days of the week for a schedule-based autoscale rule
     */
    @JvmName("dayiodwaltksskqo")
    public suspend fun days(values: List<Output<Either<String, DaysOfWeek>>>) {
        this.days = Output.all(values)
    }

    /**
     * @param value Time and capacity for a schedule-based autoscale rule
     */
    @JvmName("bdisbksnjtdifhdb")
    public suspend fun timeAndCapacity(`value`: Output<AutoscaleTimeAndCapacityArgs>) {
        this.timeAndCapacity = value
    }

    /**
     * @param value Days of the week for a schedule-based autoscale rule
     */
    @JvmName("wfgiwkfobcosdugw")
    public suspend fun days(`value`: List<Either<String, DaysOfWeek>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.days = mapped
    }

    /**
     * @param values Days of the week for a schedule-based autoscale rule
     */
    @JvmName("pbovyhqcgpdkkxam")
    public suspend fun days(vararg values: Either<String, DaysOfWeek>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.days = mapped
    }

    /**
     * @param value Time and capacity for a schedule-based autoscale rule
     */
    @JvmName("wpvnnweykpcklynw")
    public suspend fun timeAndCapacity(`value`: AutoscaleTimeAndCapacityArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeAndCapacity = mapped
    }

    /**
     * @param argument Time and capacity for a schedule-based autoscale rule
     */
    @JvmName("wkstcjqqfbcawkeo")
    public suspend
    fun timeAndCapacity(argument: suspend AutoscaleTimeAndCapacityArgsBuilder.() -> Unit) {
        val toBeMapped = AutoscaleTimeAndCapacityArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.timeAndCapacity = mapped
    }

    internal fun build(): AutoscaleScheduleArgs = AutoscaleScheduleArgs(
        days = days,
        timeAndCapacity = timeAndCapacity,
    )
}
